<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
CONSTANTS
=================================================================================================================
*/
if ( ! defined ( 'MIXANO_DIR' ) ){
	define( 'MIXANO_DIR', get_template_directory() );
}

if ( ! defined ( 'MIXANO_URI' ) ){
	define( 'MIXANO_URI', get_template_directory_uri() );
}


/*
=================================================================================================================
Mixano_Core_Setup - requires, enqueues , theme support etc.
=================================================================================================================
*/
class Mixano_Core_Setup{
	
	public function __construct() {
		add_action( 'after_setup_theme', array( $this, 'requires' ), 4 );
		add_action( 'after_setup_theme', array( $this, 'theme_support') );
		add_action( 'admin_init', array( $this, 'add_editor_styles') );
	}

	public function requires(){
		//theme requires
		require_once( MIXANO_DIR.'/inc/functions/theme.php' ); //theme related functions
		require_once( MIXANO_DIR.'/inc/functions/ads.php' ); //ads functions
		require_once( MIXANO_DIR.'/inc/functions/enqueue.php' ); //enqueue css and js
		require_once( MIXANO_DIR.'/inc/functions/wordpress.php' ); //wordpress related functions
		require_once( MIXANO_DIR.'/inc/functions/svg.php' ); //svg icons
		require_once( MIXANO_DIR.'/inc/functions/svg-brands.php' ); //svg brand icons
		require_once( MIXANO_DIR.'/inc/functions/customizer.php' ); //customizer
		require_once( MIXANO_DIR.'/inc/functions/colors.php' ); //colors
		require_once( MIXANO_DIR.'/options/options.php' ); //theme options
		require_once( MIXANO_DIR.'/inc/functions/custom-css.php' ); //custom css
		require_once( MIXANO_DIR .'/inc/tgm/class-tgm-plugin-activation.php' );
		require_once( MIXANO_DIR .'/inc/tgm/class-tgm-updater.php' );
		require_once( MIXANO_DIR .'/inc/functions/activation.php' );
	}

	public function theme_support(){
		if ( ! isset( $content_width ) ) $content_width = 1200;
		if( function_exists( 'add_theme_support' ) ){
			
			add_theme_support( 'post-formats', array( 'video', 'gallery', 'audio' ) );
			
			//theme support
			add_theme_support( 'post-thumbnails' );
			add_theme_support( 'automatic-feed-links' );
			add_theme_support( 'html5' );
			add_theme_support( 'title-tag' );
			add_theme_support( 'editor-styles' );            
			
			//admin thumb size
			add_image_size( 'mixano-admin-thumb', 100, 100, true );
			
			//cropped image sizes
			add_image_size( 'mixano-grid', 510, 403, true );
			add_image_size( 'mixano-blog-classic', 963, 494, true );
			add_image_size( 'mixano-full-single', 960, 900, true );
			add_image_size( 'mixano-widget', 120, 90 , true );			
			
			//original image sizes
			add_image_size( 'mixano-grid-original', 510, 403, false );
			add_image_size( 'mixano-blog-classic-original', 963, 494, false );
			add_image_size( 'mixano-full-single-original', 960, 900, false );
			add_image_size( 'mixano-widget-original', 120, 90 , false );
			
			//logo support
			$defaults_logo = array(
				'height'      => 100,
				'width'       => 400,
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
			);
			add_theme_support( 'custom-logo', $defaults_logo );			
			
			//custom background support
			$defaults_bg = array(
				'default-repeat'         => 'no-repeat',
				'default-attachment'     => 'fixed',
			);
			add_theme_support( 'custom-background', $defaults_bg );
			
			//custom header support
			$defaults_header = array(
				'width'         => 1200,
				'height'        => 300,
				'uploads'       => true,
				'wp-head-callback'  => 'mixano_header_text_customizer',
				'default-text-color' => '#001b49'
				
			);
			add_theme_support( 'custom-header', $defaults_header );		
			
			add_theme_support( 'customize-selective-refresh-widgets' );

		}
		
		//Make theme available for translation.
		load_theme_textdomain( 'mixano' , MIXANO_DIR. '/languages' );
		
		//Register primary menu
		register_nav_menus( array(
			'primary' => esc_html__('Primary Menu', 'mixano'),
		) );
		
	}
	
	public function add_editor_styles() {
		add_editor_style( 'css/mixano-editor-style.css' );
	}

}

# GO!
new Mixano_Core_Setup;