<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
mixano_process_colors - process colors and return the css
=================================================================================================================
*/
function mixano_process_colors( $args = array() ){
	$output = '';
	
	//color 1
	$output .= '
		a,
		a:hover,
		.color-1,
		.widget .color-1,
		.widget a:hover,
		.sub-menu .current-menu-item > a,
		.sub-menu a:hover,
		ul.tags a:hover,
		.widget th a,
		.widget td a,
		.main-color-1,
		.author-details .social-profiles a:hover,
		.comment-reply:hover a,
		.page-content a:hover,
		.post-content a:hover,
		.post-category.single .category-link:hover,
		.single .author-link:hover,
		.author-details .social-profiles a{
			color:'.esc_attr( $args['color-1'] ).'
		}
		.bg-color-1,
		.pagination a:hover,
		.pagination li.active a,
		.single .pagination span.current,
		input[type="submit"],
		button,
		a.button,
		#after-footer .search-button,
		.wp-block-quote::before,
		.wp-block-pullquote::before,
		blockquote::before,
		.post-details .downloads:after,
		.popular .vertical-line:after,
		.main-bg-1,
		#searchform a.submit,
		#freebies .vertical-text,
		.highlight:before,
		.big-category,
		.post-content ul li:not(.blocks-gallery-item):before,
		.page-content ul li:before,
		#comments ul li:before,
		.menu .sub-menu a:after,
		.popular-carousel > .slick-arrow.slick-next,
		.popular-carousel > .slick-arrow.slick-prev,
		.post-content p a:after ,
		.page-content p a:after,
		.intro:hover:after,
		.article-details .category-link:after,
		header#theme-header .logo::after,
		.subscribe:after,
		.author-details .social-profiles a:after,
		.wp-block-button:not(.is-style-outline) .wp-block-button__link,
		nav.primary.open #primary.menu,
		.go_up_btn{
			background-color:'.esc_attr( $args['color-1'] ).'
		}
		.search-button:hover,
		.post-content,
		.search-button,
		.tagcloud a:hover,
		.tags a:hover{
			border-color:'.esc_attr( $args['color-1'] ).'
		}
		
		.author-box .social-profiles svg{
			fill:'.esc_attr( $args['color-1'] ).'
		}		
		
	';	
		
		
	$output .= '
		header#theme-header,
		.articles .article:after,
		.category-count a:after,
		.popular-carousel .slick-slide:after,
		.post-title a:hover{
			background-image: linear-gradient(90deg, '.esc_attr( $args['color-1'] ).' 0%, '.esc_attr( $args['color-2'] ).' 100%);
		}
	';		
	
	$output .= '
		::-moz-selection {
		  background: '.esc_attr( $args['color-1'] ).';
		}

		::selection {
		  background: '.esc_attr( $args['color-1'] ).';
		}
	';	
	
	//color 2
	$output .= '
		.color-2,
		.widget .color-2{
			color:'.esc_attr( $args['color-2'] ).'
		}
		button:hover,
		a.button:hover,
		.bg-color-2,
		input[type="submit"]:hover,
		.wp-block-button:not(.is-style-outline) .wp-block-button__link:hover{
			background-color:'.esc_attr( $args['color-2'] ).'
		}		
	';	
	
	//color 3
	$output .= '
		body,
		.body-color,
		.pagination a,
		.tagcloud a,
		ul.tags a,
		.widget h2,
		.upper-heading,
		.social-profiles.share a,
		.widget .wp-caption-text{
			color:'.esc_attr( $args['color-3'] ).'
		}
		.social-profiles.share svg{
			fill:'.esc_attr( $args['color-3'] ).'
		}
	';	
	
	//color 4
	$output .= '
		h1, h1 a,
		h2, h2 a,
		h3, h3 a,
		h4, h4 a,
		h5, h5 a,
		h6, h6 a,
		.widget a,
		.sub-menu a,
		header .logo h1,
		.comment-reply a,
		.category-link,
		.arrow-read-more-2,
		.social-profiles.share li:first-child,
		.post-content,
		.page-content{
			color:'.esc_attr( $args['color-4'] ).'
		}	
	';	
	
	//color 5
	$output .= '
		.popular,
		footer#footer,
		footer#footer:before,
		.copyright,
		.intro-holder,
		.site-grid:before,
		.article-details,
		.article-image,
		.breadcrumb-navigation,
		.carousel-holder,
		#ad-header{
			background:'.esc_attr( $args['color-5'] ).'
		}
		@media (max-width:1023px){
			.menu > li > a > svg{
				background:'.esc_attr( $args['color-5'] ).'
			}
		}		
		.border-left-right.big-category a,
		.border-left.big-category a{
			color:'.esc_attr( mixano_hex ( $args['color-5'] , .1 ) ).';
		}			
		.border-left-right.big-category a:hover,
		.border-left.big-category a:hover{
			color:'.esc_attr( mixano_hex ( $args['color-5'] , .4 ) ).';
		}			
	';

	
	return $output;
}


function mixano_get_main_color(){
	if ( mixano_option( 'color-scheme' )  == 'custom' ) {
		$color = mixano_option( 'colors', 'color-1' );
	}
	else{
		if (  mixano_option( 'skin-colors') == 'set1' ){
			$color = '#ff4f37';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set2' ){
			$color = '#E91E63';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set3' ){
			$color = '#8BC34A';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set4' ){
			$color = '#ff4364';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set5' ){
			$color = '#2196F3';
		}
		elseif (  mixano_option( 'skin-colors') == 'set6' ){
			$color = '#ff9800';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set7' ){
			$color = '#ff4091';
		}
	}
	return $color;
}

function mixano_get_main_color2(){
	if ( mixano_option( 'color-scheme' )  == 'custom' ) {
		$color = mixano_option( 'colors', 'color-2' );
	}
	else{
		if (  mixano_option( 'skin-colors') == 'set1' ){
			$color = '#fe803b';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set2' ){
			$color = '#745bff';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set3' ){
			$color = '#00BCD4';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set4' ){
			$color = '#d90429';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set5' ){
			$color = '#07c8f9';
		}
		elseif (  mixano_option( 'skin-colors') == 'set6' ){
			$color = '#ff5722';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set7' ){
			$color = '#FFC107';
		}
	}
	return $color;
}


function mixano_get_dark_color(){
	if ( mixano_option( 'color-scheme' )  == 'colors' ) {
		$color = mixano_option( 'colors', 'color-5' );
	}
	else{
		if (  mixano_option( 'skin-colors') == 'set1' ){
			$color = '#0e1121';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set2' ){
			$color = '#2d2146';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set3' ){
			$color = '#191d19';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set4' ){
			$color = '#21181a';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set5' ){
			$color = '#0d1927';
		}
		elseif (  mixano_option( 'skin-colors') == 'set6' ){
			$color = '#1a1412';
		}		
		elseif (  mixano_option( 'skin-colors') == 'set7' ){
			$color = '#250b1d';
		}
	}
	return $color;
}