<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
mixano_load_styles() - enqueue CSS files
=================================================================================================================
*/
function mixano_load_styles(){
	
	wp_enqueue_style( 'mixano-style' , MIXANO_URI.'/style.css', array(), '1.0', 'all' );
	mixano_enqueue_fonts();
	
}
add_action( 'wp_enqueue_scripts' , 'mixano_load_styles', 10 );

/*
=================================================================================================================
mixano_add_fonts_css() - Add theme default fonts
=================================================================================================================
*/
function mixano_add_fonts_css(){
	
	$body_font_arr = mixano_option( 'body-typography' );
	$body_font = !empty(  $body_font_arr['font-family'] ) ? $body_font_arr['font-family'] : 'Roboto';		

	$heading_font_arr = mixano_option( 'heading-typography' );
	$heading_font = !empty(  $heading_font_arr['font-family'] ) ? $heading_font_arr['font-family'] : 'Space Grotesk';
	$heading_font_w = !empty(  $heading_font_arr['font-weight'] ) ? $heading_font_arr['font-weight'] : '700';

	$css = '
			body,.primary-font{font-family:'.esc_attr( $body_font ).', Arial} 
			h1,h2,h3,h4,h5,h6,.secondary-font, .overlay-text:after, .date-published span.big{font-family:'. esc_attr( $heading_font ) .', Arial}
		';
	if ( $heading_font == 'Space Grotesk' ){
		$css .= '@font-face {
			font-family: "Space Grotesk";
			font-weight: 700;
			src: url("'.esc_url( MIXANO_URI ).'/fonts/spacegrotesk-bold-webfont.woff2") format("woff2");
			font-style: normal;

		}

		@font-face {
			font-family: "Space Grotesk";
			font-weight: 400;
			src: url("'.esc_url( MIXANO_URI ).'/fonts/spacegrotesk-regular-webfont.woff2") format("woff2");
			font-style: normal;

		}';
	}			
		
	wp_add_inline_style( 'mixano-custom-css', $css );
	
}
add_action( 'wp_enqueue_scripts','mixano_add_fonts_css' );

/*
=================================================================================================================
mixano_enqueue_fonts() - Enqueue fonts
=================================================================================================================
*/
function mixano_enqueue_fonts(){

	$body_font_arr = mixano_option( 'body-typography' );
	$body_font = !empty(  $body_font_arr['font-family'] ) ? $body_font_arr['font-family'] : 'Roboto';	
	$body_font_w = !empty(  $body_font_arr['font-weight'] ) ? $body_font_arr['font-weight'] : '400';	
	
	$heading_font_arr = mixano_option( 'heading-typography' );
	$heading_font = !empty(  $heading_font_arr['font-family'] ) ? $heading_font_arr['font-family'] : 'Space Grotesk';
	$heading_font_w = !empty(  $heading_font_arr['font-weight'] ) ? $heading_font_arr['font-weight'] : '700';

	$google_fonts = esc_attr( $heading_font .':'. $heading_font_w .'|'. $body_font .':'. $body_font_w. '|Roboto:700'  );
	
	wp_enqueue_style( 'mixano-custom-css', 'https://fonts.googleapis.com/css?family='.$google_fonts.'&display=swap' );
}

/*
=================================================================================================================
mixano_custom_font_weight() - Output custom font weight in CSS
=================================================================================================================
*/
function mixano_custom_font_weight(){
	$css = '';
	$has_weight = mixano_option('heading-typography','font-weight');
	$has_font = mixano_option('heading-typography','font-family');
	if ( $has_weight && !empty ( $has_font ) ){
		$css='h1,h2,h3,h4,h5,h6,.date-published span.big,.arrow-read-more-2,#freebies .vertical-text,.overlay-text:after,.widget a{ font-weight:'.esc_attr( $has_weight ).' }';
	}
	wp_add_inline_style( 'mixano-custom-css', $css );
}
add_action( 'wp_enqueue_scripts','mixano_custom_font_weight' );

/*
=================================================================================================================
mixano_load_scripts() - enqueue js files
=================================================================================================================
*/
function mixano_load_scripts(){
	
	//slick slider
	mixano_slick_enqueue();
	
	wp_register_script( 'mixano-scripts', MIXANO_URI."/js/scripts.js",  array( 'jquery' ), '', true );

	$data = array( 'nonce' => wp_create_nonce( 'mixano_count_downloads' ), 'ajax_url' => admin_url( 'admin-ajax.php' ), 'slick_how_many' => mixano_option( 'carousel-popular' ) , 'pointer_color' => mixano_get_main_color() , 'pointer' => mixano_option('enable-cursor'), 'sticky' => mixano_option('enable-sticky') ,
	'main_color1' => mixano_get_main_color(), 'main_color2' => mixano_get_main_color2());
	wp_localize_script( 'mixano-scripts', 'mixano_data', $data );	
	
	wp_enqueue_script( 'mixano-scripts');

	if ( mixano_option( 'lazy-load' )  == '1' ){
		$data = array( 'url' => MIXANO_URI );
		wp_enqueue_script( 'lazy', MIXANO_URI."/js/lazy.js", array( 'jquery' ), '', true ); //no need to prefix as it's 3rd party script
		wp_localize_script( 'lazy', 'mixano_object_name', $data );
	}
	
}
add_action( 'wp_enqueue_scripts' , 'mixano_load_scripts' , 1 );

/*
=================================================================================================================
mixano_slick_enqueue() - enqueue slick only when necessary
=================================================================================================================
*/
function mixano_slick_enqueue(){
	global $wp_query;
	
	$posts = is_array( $wp_query->posts ) ? $wp_query->posts : '';

	if ( is_array( $posts ) ){
		foreach( $posts as $post ){
			if ( get_post_format( $post->ID ) == 'gallery' ){
				wp_enqueue_script( 'slick', MIXANO_URI."/js/slick.min.js",  array( 'jquery' ), '', true );
				continue;
			}
		}
	}
	if ( mixano_option( 'enable-popular' ) == 1  ){
		wp_enqueue_script( 'slick', MIXANO_URI."/js/slick.min.js",  array( 'jquery' ), '', true );
	}
}


/*
=================================================================================================================
mixano_gutenberg_gallery_enqueue() - enqueue CSS and JS gallery only if needed
=================================================================================================================
*/
function mixano_gutenberg_gallery_enqueue(){
		
	if ( is_singular('post') ){
			
		$post = get_post();
		
		//backward compatibility - function "has_blocks()" was introduced in WordPress 5.0.0
		if ( function_exists( 'has_blocks' ) ){
			if ( has_blocks( $post->post_content ) ) {
				$blocks = parse_blocks( $post->post_content );
				foreach ( $blocks as  $block ){
					if( $block['blockName'] === 'core/gallery' && !empty( $block['attrs']['linkTo'] ) ){
						wp_enqueue_style( 'simple-lightbox' , MIXANO_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' ); //no need to prefix as it's 3rd party style
						wp_enqueue_script( 'simple-lightbox', MIXANO_URI."/js/simple-lightbox.min.js", array( 'jquery' ), '', true ); //no need to prefix as it's 3rd party script
						wp_enqueue_script( 'mixano-simple-lightbox-init', MIXANO_URI."/js/simple-lightbox.init.js", array( 'simple-lightbox' ), '', true );
					}
				}
			}
		}
		else{
			wp_enqueue_style( 'simple-lightbox' , MIXANO_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' ); //no need to prefix as it's 3rd party style
			wp_enqueue_script( 'simple-lightbox', MIXANO_URI."/js/simple-lightbox.min.js", array( 'jquery' ), '', true );	//no need to prefix as it's 3rd party script
			wp_enqueue_script( 'mixano-simple-lightbox-init', MIXANO_URI."/js/simple-lightbox.init.js", array( 'simple-lightbox' ), '', true );
		}
	
	}
}

add_action( 'get_footer','mixano_gutenberg_gallery_enqueue',1 );
	

/*
=================================================================================================================
mixano_widget_gallery_enqueue() - enqueue CSS and JS if widget has gallery
=================================================================================================================
*/
function mixano_widget_gallery_enqueue(){
	$widgets = wp_get_sidebars_widgets();
	unset( $widgets['wp_inactive_widgets'] );
	foreach ( $widgets as $widget ){
		foreach ( $widget as $w ){
			if ( stripos ( $w, 'media_gallery'  ) !== false ){
				wp_enqueue_style( 'simple-lightbox' , MIXANO_URI.'/css/simple-lightbox.min.css', array(), '1.0', 'all' ); //no need to prefix as it's 3rd party style
				wp_enqueue_script( 'simple-lightbox', MIXANO_URI."/js/simple-lightbox.min.js", array( 'jquery' ), '', true ); //no need to prefix as it's 3rd party script					
			}
		}
	}
}
add_action( 'get_footer','mixano_widget_gallery_enqueue',1 );
/*
=================================================================================================================
mixano_load_admin_styles() - enqueue the CSS files in admin
=================================================================================================================
*/
function mixano_load_admin_styles() {
	
	if ( is_customize_preview() ){
		wp_enqueue_style( 'mixano-admin' , MIXANO_URI.'/css/admin.css', array(), '1.0', 'all' );
	}
	
	$screen = get_current_screen();

	if ( $screen->id == 'post' || $screen->id == 'page' ) {
		wp_enqueue_style( 'mixano-admin-editor-font', 'https://fonts.googleapis.com/css?family=Roboto:400,700&display=swap' );
	}			
}
add_action( 'admin_enqueue_scripts', 'mixano_load_admin_styles' );